@@ -1,12 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-roam-ql" "0.2"
+(define-package "org-roam-ql" "20251021.559"
   "Interface to query and view results from org-roam."
   '((emacs            "28")
     (org-roam         "2.2.0")
     (s                "1.12.0")
     (magit-section    "3.3.0")
     (transient        "0.4")
-    (org-super-agenda "1.2"))
+    (org-super-agenda "1.2")
+    (dash             "2.0"))
   :url "https://github.com/ahmed-shariff/org-roam-ql"
-  :commit "f628fef081394f159f196f4350132aecb3edb8cc"
-  :revdesc "f628fef08139")
+  :commit "a207462ec885662ba38a93d3d8cd78a31795db97"
+  :revdesc "a207462ec885")
